@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '1.22'; # VERSION
+our $VERSION = '1.23'; # VERSION
 
 
 use strict;
@@ -34,7 +34,7 @@ BEGIN {
 }
 
 
-get '/' => sub { shift->render(text => "welcome to Yars") } => 'index';
+get '/' => sub { shift->render(text => "welcome to Yars", format => 'txt', status => 200 ) } => 'index';
 
 
 get  '/file/#filename/:md5' => [ md5 => qr/[a-f0-9]{32}/ ] => \&_get;
@@ -205,7 +205,7 @@ put '/file/#filename/:md5' => { md5 => 'calculate' } => sub {
     if ($c->req->headers->header('X-Yars-Stash')) {
         DEBUG "Stashing a file that is not ours : $digest $filename";
         _stash_locally($c, $filename, $digest, $asset) and return;
-        return $c->render->exception("Cannot stash $filename locally");
+        return $c->reply->exception("Cannot stash $filename locally");
     }
 
     DEBUG "Received NoStash for $filename" if $c->req->headers->header('X-Yars-NoStash');
@@ -400,7 +400,7 @@ sub _del {
         DEBUG "This is our file, we will delete it.";
         my $dir  = $c->tools->storage_path( $md5 );
         if (-r "$dir/$filename") {
-            unlink "$dir/$filename" or return $c->render->exception($!);
+            unlink "$dir/$filename" or return $c->reply->exception($!);
             $c->tools->cleanup_tree($dir);
             return $c->render(status => 200, text =>'ok');
         }
@@ -411,7 +411,7 @@ sub _del {
     }
 
     if (my $dir = $c->tools->local_stashed_dir($filename,$md5)) {
-        unlink "$dir/$filename" or return $c->render->exception($!);
+        unlink "$dir/$filename" or return $c->reply->exception($!);
         $c->tools->cleanup_tree($dir);
         return $c->render(status => 200, text =>'ok');
     }
@@ -424,7 +424,7 @@ sub _del {
         my $error = $tx->error;
         my ($msg,$code) = ($error->{message}, $error->{code});
         return $c->render(status => $code, text => $msg) if $code;
-        return $c->render->exception("Error deleting from $server ".format_tx_error($tx->error));
+        return $c->reply->exception("Error deleting from $server ".format_tx_error($tx->error));
     }
 };
 
@@ -476,7 +476,7 @@ post '/disk/status' => sub {
     my $c = shift;
     my $got = $c->parse_autodata;
     my $root = $got->{root} || $got->{disk};
-    my $state = $got->{state} or return $c->render->exception("no state found in request");
+    my $state = $got->{state} or return $c->reply->exception("no state found in request");
     my $server = $got->{server};
     if ($server && $server ne $c->tools->server_url) {
         unless ($c->tools->server_exists($server)) {
@@ -654,7 +654,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
@@ -662,22 +662,25 @@ version 1.22
 
 =head1 DESCRIPTION
 
-This document provides information on the Yars specific REST API (the HTTP "routes") provided
-by Yars servers.  For a Perl interface to this API, see L<Yars::Client>.  For a command line
-interface see L<yarsclient>.  For the generic L<Clustericious> REST API that comes with all
-L<Clustericious> services, see L<Clustericious::RouteBuilder::Common>.
+This document provides information on the Yars specific REST API (the 
+HTTP "routes") provided by Yars servers.  For a Perl interface to this 
+API, see L<Yars::Client>.  For a command line interface see 
+L<yarsclient>.  For the generic L<Clustericious> REST API that comes 
+with all L<Clustericious> services, see 
+L<Clustericious::RouteBuilder::Common>.
 
 =head1 ROUTES
 
 =head2 GET /
 
-Get a welcome message.  This is usually simply the text string "welcome to Yars".
+Get a welcome message.  This is usually simply the text string "welcome 
+to Yars".
 
 =head2 GET /file/#filename/:md5, GET /:md5/#filename
 
 Retrieve a file with the given name and md5.
 
-You can also make a HEAD request on the same route to determine if the
+You can also make a HEAD request on the same route to determine if the 
 file is available without making the yars server send the file.
 
 =head2 PUT /file/#filename/#md5
@@ -701,10 +704,9 @@ as JSON encoded in the body.
 
 =head2 POST /check/manifest
 
-Given JSON with 'manifest' which is a return-delimited string
-of filenames and md5s (like the output of md5sum), check each
-file for existence on the server (or proxy to the right
-server)
+Given JSON with 'manifest' which is a return-delimited string of 
+filenames and md5s (like the output of md5sum), check each file for 
+existence on the server (or proxy to the right server)
 
 =head2 GET /servers/status
 
